.. currentmodule:: dsss

API reference
*************

.. automodule:: dsss

.. autosummary::
   :toctree: _api
   :recursive:

   availability
   common
   config
   data
   metadata
   registration
   schema
   starlette
   store
   structure
   testing
